@@ -17,9 +17,9 @@
 ** 
 ** You should have received a copy of the GNU Lesser General Public
 ** License along with this library; if not, write to the Free Software
-** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 **
-** See http://www.matroska.org/license/lgpl/ for LGPL licensing information.**
+** See http://www.gnu.org/licenses/lgpl-2.1.html for LGPL licensing information.**
 ** Contact license@matroska.org if any conditions of this licensing are
 ** not clear to you.
 **
@@ -70,7 +70,7 @@ class MATROSKA_DLL_API DataBuffer {
 		{
 			if (bInternalBuffer)
 			{
-				myBuffer = new binary[mySize];
+				myBuffer = new (std::nothrow) binary[mySize];
 				if (myBuffer == NULL)
 					bValidValue = false;
 				else
@@ -84,7 +84,7 @@ class MATROSKA_DLL_API DataBuffer {
 		virtual binary * Buffer() {assert(bValidValue); return myBuffer;}
 		virtual uint32   & Size() {return mySize;};
 		virtual const binary * Buffer() const {assert(bValidValue); return myBuffer;}
-		virtual const uint32   Size()   const {return mySize;};
+		virtual uint32   Size()   const {return mySize;};
 		bool    FreeBuffer(const DataBuffer & aBuffer) {
 			bool bResult = true;
 			if (myBuffer != NULL && bValidValue) {
@@ -305,7 +305,6 @@ class MATROSKA_DLL_API KaxSimpleBlock : public KaxInternalBlock {
 		bool IsKeyframe() const    { return bIsKeyframe; }
 		bool IsDiscardable() const { return bIsDiscardable; }
 
-		operator KaxInternalBlock &() { return *this; }
 		void SetParent(KaxCluster & aParentCluster);
 
         EBML_CONCRETE_CLASS(KaxSimpleBlock)
