@@ -17,9 +17,9 @@
 ** 
 ** You should have received a copy of the GNU Lesser General Public
 ** License along with this library; if not, write to the Free Software
-** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 **
-** See http://www.matroska.org/license/lgpl/ for LGPL licensing information.**
+** See http://www.gnu.org/licenses/lgpl-2.1.html for LGPL licensing information.**
 ** Contact license@matroska.org if any conditions of this licensing are
 ** not clear to you.
 **
@@ -161,7 +161,7 @@ LacingType KaxInternalBlock::GetBestLacingType() const {
 		return LACING_EBML;
 }
 
-filepos_t KaxInternalBlock::UpdateSize(bool bSaveDefault, bool bForceRender)
+filepos_t KaxInternalBlock::UpdateSize(bool /* bSaveDefault */, bool /* bForceRender */)
 {
 	LacingType LacingHere;
     assert(EbmlBinary::GetBuffer() == NULL); // Data is not used for KaxInternalBlock
@@ -238,7 +238,7 @@ KaxBlockVirtual::~KaxBlockVirtual()
         SetBuffer( NULL, 0 ); 
 }
 
-filepos_t KaxBlockVirtual::UpdateSize(bool bSaveDefault, bool bForceRender)
+filepos_t KaxBlockVirtual::UpdateSize(bool /* bSaveDefault */, bool /* bForceRender */)
 {
 	assert(TrackNumber < 0x4000);
 	binary *cursor = EbmlBinary::GetBuffer();
@@ -268,7 +268,7 @@ filepos_t KaxBlockVirtual::UpdateSize(bool bSaveDefault, bool bForceRender)
 	\todo more optimisation is possible (render the Block head and don't copy the buffer in memory, care should be taken with the allocation of Data)
 	\todo the actual timecode to write should be retrieved from the Cluster from here
 */
-filepos_t KaxInternalBlock::RenderData(IOCallback & output, bool bForceRender, bool bSaveDefault)
+filepos_t KaxInternalBlock::RenderData(IOCallback & output, bool /* bForceRender */, bool /* bSaveDefault */)
 {
 	if (myBuffers.size() == 0) {
 		return 0;
@@ -1034,7 +1034,7 @@ void KaxBlockBlob::SetBlockGroup( KaxBlockGroup &BlockRef )
 	Block.group = &BlockRef;
 }
 
-filepos_t KaxBlockVirtual::ReadData(IOCallback & input, ScopeMode ReadFully)
+filepos_t KaxBlockVirtual::ReadData(IOCallback & input, ScopeMode /* ReadFully */)
 {
     input.setFilePointer(SizePosition + CodedSizeLength(Size, SizeLength, bSizeIsFinite) + Size, seek_beginning);
     return GetSize();
