@@ -7,24 +7,21 @@
 **
 ** This file is part of libmatroska.
 **
-** This file may be distributed under the terms of the Q Public License
-** as defined by Trolltech AS of Norway and appearing in the file
-** LICENSE.QPL included in the packaging of this file.
-**
-** This file may be distributed and/or modified under the terms of the
-** GNU General Public License version 2 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.
-**
-** Licensees holding an other license may use this file in accordance with 
-** the Agreement provided with the Software.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-**
-** See http://www.matroska.org/license/qpl/ for QPL licensing information.
-** See http://www.matroska.org/license/gpl/ for GPL licensing information.
+** This library is free software; you can redistribute it and/or
+** modify it under the terms of the GNU Lesser General Public
+** License as published by the Free Software Foundation; either
+** version 2.1 of the License, or (at your option) any later version.
+** 
+** This library is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+** Lesser General Public License for more details.
+** 
+** You should have received a copy of the GNU Lesser General Public
+** License along with this library; if not, write to the Free Software
+** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 **
+** See http://www.gnu.org/licenses/lgpl-2.1.html for LGPL licensing information.**
 ** Contact license@matroska.org if any conditions of this licensing are
 ** not clear to you.
 **
@@ -32,7 +29,7 @@
 
 /*!
     \file
-    \version \$Id: test0.cpp 383 2010-07-04 09:17:57Z robux4 $
+    \version \$Id$
     \author Steve Lhomme     <robux4 @ users.sf.net>
 		Test the EBML write possibilities
 		\see http://www.cl.cam.ac.uk/~mgk25/unicode.html
@@ -51,8 +48,9 @@
 #include "ebml/EbmlMaster.h"
 #include "ebml/EbmlFloat.h"
 #include "ebml/EbmlStream.h"
+#include "ebml/StdIOCallback.h"
 
-using namespace LIBMATROSKA_NAMESPACE;
+using namespace LIBEBML_NAMESPACE;
 
 const char RW_FILENAME[] = "test.kax";
 
